@@ -1,4 +1,6 @@
 """ Integration tests for Quilt Packages. """
+import io
+from contextlib import redirect_stderr
 from io import BytesIO
 import os
 import pathlib
@@ -531,8 +533,13 @@ class PackageTest(QuiltTestCase):
         remote_pkg.set('foo2', test_file3)
 
         with patch('time.time', return_value=1234567891), \
+             patch('quilt3.packages.DISABLE_TQDM', True), patch('quilt3.data_transfer.DISABLE_TQDM', True), \
              patch('quilt3.data_transfer.s3_transfer_config.max_request_concurrency', 1):
-            remote_pkg.push('Quilt/package', 's3://my_test_bucket/')
+            stderr = io.StringIO()
+
+            with redirect_stderr(stderr), patch('quilt3.packages.DISABLE_TQDM', True):
+                remote_pkg.push('Quilt/package', 's3://my_test_bucket/')
+            assert not stderr.getvalue()
 
 
     def test_package_deserialize(self):
@@ -1325,9 +1332,40 @@ class PackageTest(QuiltTestCase):
             }
         )
 
+        self.s3_stubber.add_response(
+            method='get_object',
+            service_response={
+                'VersionId': 'v1',
+                'Body': BytesIO(b'abcdef'),
+            },
+            expected_params={
+                'Bucket': 'my-test-bucket',
+                'Key': '.quilt/named_packages/test/foo/latest',
+            }
+        )
+
+        # import fails for installation outside named package directory
+
         with patch('quilt3.data_transfer.s3_transfer_config.max_request_concurrency', 1):
             Package.install('Quilt/Foo', registry='s3://my-test-bucket', dest='package/')
 
+            with patch('quilt3.Package._browse') as browse_mock, pytest.raises(ImportError) as exc_info:
+                browse_mock.return_value = quilt3.Package()
+                from quilt3.data.Quilt import Foo
+            assert "cannot import name 'Foo'" in str(exc_info.value)
+
+        # make sure import works for an installed named package
+
+        with patch('quilt3.data_transfer.s3_transfer_config.max_request_concurrency', 1):
+            Package.install('test/foo', registry='s3://my-test-bucket')
+
+            with patch('quilt3.Package._browse') as browse_mock:
+                browse_mock.return_value = quilt3.Package()
+                from quilt3.data.test import foo
+
+                assert isinstance(foo, Package)
+                browse_mock.assert_called_once()
+
     @pytest.mark.usefixtures('isolate_packages_cache')
     @patch('quilt3.data_transfer.s3_transfer_config.max_request_concurrency', 1)
     @patch('quilt3.packages.ObjectPathCache.set')
@@ -1348,7 +1386,7 @@ class PackageTest(QuiltTestCase):
         path = pathlib.Path.cwd() / dest / 'bat'
         mocked_cache_set.assert_called_once_with(
             entry_url,
-            str(path),
+            PhysicalKey.from_path(path).path,
         )
         assert path.read_bytes() == entry_content
 
@@ -1372,7 +1410,7 @@ class PackageTest(QuiltTestCase):
         path = pathlib.Path.cwd() / dest / 'bat'
         mocked_cache_set.assert_called_once_with(
             entry_url,
-            str(path),
+            PhysicalKey.from_path(path).path,
         )
         assert path.read_bytes() == entry_content
 
